==> ZenTaoPMS.17.2.php5.4_5.6.zip: zentaopms/extension/biz/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPwvyJeyJnRAWKiZRhEUU0U0JeC/LhgkKGbAOXSChMLIzcHsscb4dSQaxdh7XCqV5WIq5RTMp
zg+uS1bUf44leQhPTV7fqNOSz6oTjI+QZhsd1cbB4S8pAO7NGL2+W3UxH7ixHlmTqogSRdq7Df0p
rql7+SVNui3NQZaqXCf6RuxmRk3kZHaV/3KnpdubQ+ndTXEEMyMSYCSOTlyzHAuRcilF2XjGsD+u
8vpPqmNL0qSGp/FxzKGr/fGPR8TuTBYrsRqWr/IzrhMLPtunYHgoYDbYDoMO775FoNldDgJMNdL+
l59eebujDDq2Wdi/iaL2wG3uDz93n0E0aCBD99607LdY6ihcrCpwg/Hbcyyjr+N/Nvox9PJOc37x
MCvNn9I1w5gWhdl2DAvqU0FJobD9piiY/U26S8N0M1L+fhFnpRzxo3DlBmcydBECZmRu2MmJopbN
T4uWZjw+cNRzv1+HUfCiE9a+tpyH2i7pwP5v5+RT9t+gQDGrqw+M9jd4

==> ZenTaoPMS.17.4.php7.1.zip: zentaopms/extension/biz/user/ext/model/class/bizext.class.php <==
<?php //0067d
if(!extension_loaded('ionCube Loader')){$__oc=strtolower(substr(php_uname(),0,3));$__ln='ioncube_loader_'.$__oc.'_'.substr(phpversion(),0,3).(($__oc=='win')?'.dll':'.so');if(function_exists('dl')){@dl($__ln);}if(function_exists('_il_exec')){return _il_exec();}$__ln='/ioncube/'.$__ln;$__oid=$__id=realpath(ini_get('extension_dir'));$__here=dirname(__FILE__);if(strlen($__id)>1&&$__id[1]==':'){$__id=str_replace('\\','/',substr($__id,2));$__here=str_replace('\\','/',substr($__here,2));}$__rd=str_repeat('/..',substr_count($__id,'/')).$__here.'/';$__i=strlen($__rd);while($__i--){if($__rd[$__i]=='/'){$__lp=substr($__rd,0,$__i).$__ln;if(file_exists($__oid.$__lp)){$__ln=$__lp;break;}}}if(function_exists('dl')){@dl($__ln);}}else{die('The file '.__FILE__." is corrupted.\n");}if(function_exists('_il_exec')){return _il_exec();}
$documentRoot = isset($_SERVER['SCRIPT_FILENAME']) ? dirname($_SERVER['SCRIPT_FILENAME']) : $_SERVER['DOCUMENT_ROOT'];
$link = is_file($documentRoot . '/loader-wizard.php') ? '/loader-wizard.php' : 'http://www.ioncube.com/lw/';
echo "<html>
  <head>
    <meta http-equiv='content-type' content='text/html; charset=utf-8' />
    <title>error</title>
  </head>
  <body>
    <h2 style='color:red;text-align:center'>未安装 ioncube loader</h2>
    <p>您需要安装ioncube loader才能使用该功能， 使用<a href='$link'>ioncube loader安装向导</a>。</p>
    <br /><br /><br />
    <h2 style='color:red;text-align:center'>Ioncube loader doesn't installed.</h2>
    <p>You haven't installed ioncube loader extension, please visit <a href='$link'>the install wizard</a> to install it.</p>
  </body>
</html>";
exit;

?>
HR+cPpWVHYr3vBe2hglJ3jYT6d07yTA2oiY7vSbVGyi5BchRf9zytDUW5exd/uVct2WxNBf6SfiS
bB0dIcw/9DS7/YwAdXEf3DOmSme7oSO20cRdLfok+22lWCSVBdQzqqG3FLJDiAPx+gOFwRp7nBnI
i2wGBCoUC6cXG9MFhFbT+nA8JZFu/GSoK9sKVMnQncsZ6gFkGOE0utm+ETgBDAuHaKfc8KydA9iV
L+AJ5sSQlAkqYjM8DPuMMwunYi8kuy7oFIbkSkJp6y9NZkYPTNxuZpl5tuORPFfrNGqhzEHRp4kO
35ad8VjgnIL7/3qwst60SjNRNVe8H81Vtw1LfsU+KOzbYfN3vQqzUlI6rNY64HqkJ4hwrrY8OCkJ
3121/MfiGCiLulXbMr1+arKPsxmmrJFlDFXfUPu6LMIKWdOMfdX0QinriiTxljXqfA11muVqlocF
jXHwZrzGrKUYsVPpslBx5mc95+ITo0tJJkN44TlPKCii6r5gq41InDQmcre6kV4VotDOdBfdyehE
6iE3t9aR27KtGm8qXHyj9ty2i4epSl4=
